/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "configmodel.h"
#include "configuration.h"
#include <QVariant>
#include "confighandler.h"

ConfigModel::ConfigModel(QList<Configuration*> *list, QObject *parent)
	: QAbstractListModel(parent)
{
	cfgList = list;
}

ConfigModel::~ConfigModel() {}

int ConfigModel::rowCount( const QModelIndex &parent ) const
{
	return cfgList->size();
}

QVariant ConfigModel::data( const QModelIndex &index, int role ) const
{
	if ( !index.isValid() )
		return QVariant();

	switch (role)
	{
		case Qt::DisplayRole:
			return cfgList->at(index.row())->name();
		case Qt::ToolTipRole:
			return cfgList->at(index.row())->description();
		case Qt::WhatsThisRole || Qt::StatusTipRole:
			return QString("This list shows all the available wine configurations."); // Doesn't work. Not needed anyway.
		case Qt::UserRole:
			return cfgList->at(index.row())->absolutePath();
		default:
			return QVariant();
	}
}

Qt::ItemFlags ConfigModel::flags(const QModelIndex &index) const
{
	if (!index.isValid())
		return Qt::ItemIsEnabled;

	return QAbstractItemModel::flags(index) | Qt::ItemIsEditable;
}

bool ConfigModel::setData(const QModelIndex &index, const QVariant &value, int role)
{
	if (index.isValid() && role == Qt::EditRole)
	{
		cfgList->at(index.row())->renameSelf(value.toString());
		emit dataChanged(index, index);
		return true;
	}
	return false;
}

void ConfigModel::insertConfiguration(Configuration *cfg)
{
	beginInsertRows(QModelIndex(), cfgList->size()+1, cfgList->size()+1);

	cfgList->append( cfg );

	endInsertRows();
}

bool ConfigModel::removeRows(int position, int, const QModelIndex &)
{
	if ( !cfgList->at(position)->rmSelf() )
		return false;

	delete cfgList->at(position); // delete the object
	cfgList->removeAt(position); // delete the pointer to the object

	reset(); // resets the model
	
	return true;

	// BUGGY CODE FOR MULTIPLE ROWS
	/*int row;
	for (row = 0; row < rows; row++)
	{
		if ( !cfgList->at(position + row)->rmSelf() )
		{
			--row; // Decrease row so that the erroneous row is not removed from cfgList
			break; // Stop loop on error
		}
	}
	beginRemoveRows(QModelIndex(), position, position+rows-1);
	for (int i = 0; i <= row; i++) // remove rows up to the erroneous row
	{
		delete cfgList->at(position + i); // delete the object
		cfgList->removeAt(position + i); // delete the pointer to the object
	}
	endRemoveRows();
	return true;*/
}



